@@ -10,7 +10,7 @@ from pathlib import Path
 from apacheconfig import make_loader
 from pprint import pprint
 
-__version__ = '0.5.13'
+__version__ = '0.5.15'
 
 
 def printerr(x):
@@ -52,6 +52,7 @@ class DO_WP_Maintain():
         # Internal setup
         self.allow_root = allow_root
         self.configpaths = configpaths
+        self.exec_timeout = exec_timeout
         self.verbose = verbose
         self.debug = debug
         # Other runtime checks:
@@ -675,7 +676,7 @@ Example: --run="plugin install wp-fail2ban --activate"''')
                               hume=args.hume,
                               skip_plugins=args.skip_plugins,
                               skip_themes=args.skip_themes,
-                              path_to_wpcli=args.path_to_wpcli
+                              path_to_wpcli=args.path_to_wpcli,
                               exec_timeout=args.exec_timeout)
     except Exception as exc:
         printerr(exc)
